summaryrefslogtreecommitdiffstats
path: root/webkit/fileapi/file_system_path_manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'webkit/fileapi/file_system_path_manager.h')
-rw-r--r--webkit/fileapi/file_system_path_manager.h14
1 files changed, 10 insertions, 4 deletions
diff --git a/webkit/fileapi/file_system_path_manager.h b/webkit/fileapi/file_system_path_manager.h
index 19718ae..f914a7d 100644
--- a/webkit/fileapi/file_system_path_manager.h
+++ b/webkit/fileapi/file_system_path_manager.h
@@ -20,7 +20,7 @@ class MessageLoopProxy;
namespace fileapi {
-class FileSystemMountPointProvider;
+class ExternalFileSystemMountPointProvider;
class SandboxMountPointProvider;
// TODO(kinuko): Probably this module must be called FileSystemPathUtil
@@ -81,13 +81,19 @@ class FileSystemPathManager {
bool IsRestrictedFileName(FileSystemType type,
const FilePath& filename);
- // Checks if an origin has access to a particular filesystem type.
- bool IsAllowedFileSystemType(GURL origin, FileSystemType type);
+ // Checks if an origin has access to a particular filesystem type and
+ // file element represented by |virtual_path|.
+ bool IsAccessAllowed(const GURL& origin, FileSystemType type,
+ const FilePath& virtual_path);
SandboxMountPointProvider* sandbox_provider() const {
return sandbox_provider_.get();
}
+ ExternalFileSystemMountPointProvider* external_provider() const {
+ return external_provider_.get();
+ }
+
bool is_incognito() const {
return is_incognito_;
}
@@ -96,7 +102,7 @@ class FileSystemPathManager {
const bool is_incognito_;
const bool allow_file_access_from_files_;
scoped_ptr<SandboxMountPointProvider> sandbox_provider_;
- scoped_ptr<FileSystemMountPointProvider> local_provider_;
+ scoped_ptr<ExternalFileSystemMountPointProvider> external_provider_;
DISALLOW_COPY_AND_ASSIGN(FileSystemPathManager);
};